##################################################################
# nfs-ganesha rpm build spec file for RHEL 6.4
##################################################################

Name:              nfs-ganesha
Version:           2.1.0.2
Release:           4%{?dist}
Summary:           Ganesha NFS Server
Group:             System Environment/Libraries
License:           LGPLv3+
URL:               https://github.com/nfs-ganesha/nfs-ganesha/wiki
ExclusiveArch:     x86_64
ExclusiveArch:     aarch64
Source0:           %{name}-%{version}.tar.gz
Source1:	   nfs-ganesha.conf
Source2:           org.ganesha.nfsd.conf 
Source3:           README

# Bundling exception through Fedora 23
# https://fedorahosted.org/fpc/ticket/363
Provides:          bundled(libntirpc)

#BuildRequires:     systemd
BuildRequires:     cmake28
BuildRequires:     bison
BuildRequires:     flex
BuildRequires:     pkgconfig
BuildRequires:     doxygen
BuildRequires:     krb5-devel
BuildRequires:     xfsprogs-devel
BuildRequires:     dbus-devel
#BuildRequires:     jemalloc-devel
#BuildRequires:     libnfsidmap-devel
#BuildRequires:     libwbclient-devel
BuildRequires:     libcap-devel
BuildRequires:     glusterfs-api-devel

#Requires(post):    systemd
#Requires(preun):   systemd
#Requires(postun):  systemd
Requires:          dbus
#Requires:          jemalloc
Requires:          glusterfs-api

%global _docdir_fmt %{name}

%description
NFS-Ganesha is a user mode file server with support for both the
NFS suite and 9P, the Plan 9 remote file access protocol. It uses
an internal meta data cache and state manager for performance. It
also provides support for pNFS for multiple clustered file systems
both open source and proprietary. Multiple file systems are supported
via loadable back-end drivers. The VFS back-end supports file systems
via the kernel. Other back-ends can support user mode library based
clusters such as CEPH and GLUSTERFS. There is also a PROXY back-end
which operates as an NFSv4 client.

%package docs
Summary:           Ganesha NFS Server Documentation
BuildArch:         noarch

%description docs
Documentation for nfs-ganesha

NFS-Ganesha is a user mode file server with support for both the 
NFS suite and 9P, the Plan 9 remote file access protocol. It uses 
an internal meta data cache and state manager for performance. It 
also provides support for pNFS for multiple clustered file systems 
both open source and proprietary. Multiple file systems are supported 
via loadable back-end drivers. The VFS back-end supports file systems 
via the kernel. Other back-ends can support user mode library based 
clusters such as CEPH and GLUSTERFS. There is also a PROXY back-end 
which operates as an NFSv4 client.

%prep
%setup -q

%build
cmake28 -DUSE_FSAL_GLUSTER=ON -DDEBUG_SYMS=ON -DALLOCATOR=libc -DCMAKE_BUILD_TYPE=Maintainer -DBUILD_CONFIG=everything -DCMAKE_INSTALL_PREFIX=%{buildroot}/usr
# _smp_mflags elided due to random build errors (cmake related?)
make VERBOSE=1

%install
make install

rm  %{buildroot}%{_bindir}/libntirpc.*
#chmod ugo+x  %{buildroot}%{_bindir}/ganestat.pl
#rm %{buildroot}%{_libdir}/ganesha/*.so
#install -D -p -m 0644 %{SOURCE2} %{buildroot}%{_unitdir}/nfs-ganesha.service
mkdir -p %{buildroot}%{_defaultdocdir}/%{name}
cp -p Docs/*.pdf %{buildroot}%{_defaultdocdir}/%{name}/
mkdir -p %{buildroot}/etc/glusterfs-ganesha
install -D -m 0644 %{SOURCE1} %{buildroot}/etc/glusterfs-ganesha/nfs-ganesha.conf
install -D -m 0644 %{SOURCE2} %{buildroot}/etc/glusterfs-ganesha/org.ganesha.nfsd.conf
install -D -m 0644 %{SOURCE3} %{buildroot}/etc/glusterfs-ganesha/README
export QA_SKIP_BUILD_ROOT=1

%post
/sbin/ldconfig
#%systemd_post nfs-ganesha.service

%preun
#%systemd_preun nfs-ganesha.service

%postun
/sbin/ldconfig
#%systemd_postun_with_restart nfs-ganesha.service

%files
%doc ChangeLog LICENSE.txt
#%exclude %{_defaultdocdir}/%{name}/*.pdf
%{_libdir}/*
%{_bindir}/*
/etc/glusterfs-ganesha/*

#%{_unitdir}/*

%files docs
%{_defaultdocdir}/%{name}/LICENSE.txt
#%{_defaultdocdir}/%{name}/*.pdf
%dir %{_defaultdocdir}/%{name}

%changelog
* Mon Jun 9 2014 Meghana M  <mmadhusu@redhat.com> 2.1.0.2-4
- Added org.ganesha.nfsd.conf as one of the sources.
  Added a README that explains how to enable Dbus for
  nfs-ganesha.

* Thu May 29 2014 Soumya Koduri <skoduri@redhat.com> 2.1.0.2-3
- Removed a sed expression which isnt required.

* Thu May 29 2014 Soumya Koduri <skoduri@redhat.com> 2.1.0.2-2
- Fix for rpm check_buildroot issue and added missing links of .so files

* Wed May 28 2014 Soumya Koduri <skoduri@redhat.com> 2.1.0.2-1
- Refresh of sources to NFS-Ganesha 2.1 RC1 and a coverity fix
  Changed the format of nfs-ganesha.conf from dos to unix.

* Fri May 23 2014 Soumya Koduri <skoduri@redhat.com> 2.1.0.1-2
- Fixed few issues in the NFS-Ganesha 2.1 spec file

* Mon May 12 2014 Meghana <mmadhusu@redhat.com> 2.1.0.1-1
- Refresh of sources to NFS-Ganesha 2.1 upstream release

* Mon May 5 2014 Soumya Koduri <skoduri@redhat.com> 2.1.0.1-1
- Refresh of sources to NFS-Ganesha 2.1 upstream release

* Mon Jan 27 2014 Anand Subramanian <anands@redhat.com> 2.0.0.2-4
- Fix for check_debug by Meghana and Soumya for validating debug levels

* Fri Jan 24 2014 Anand Subramanian <anands@redhat.com> 2.0.0.2-3
- Fix for debug level option num being greater than 10

* Thu Jan 23 2014 Anand Subramanian <anands@redhat.com> 2.0.0.2-2
- Fix for ports cleanup after ganesha is terminated using kill -s TERM

* Mon Jan 20 2014 Anand Subramanian <anands@redhat.com> 2.0.0.2-1
- Fix for showmount command fixed in code
- Fix for rpc ports cleanup in rhs-nfs-ganesha script and usage

* Mon Jan 6 2014 Anand Subramanian <anands@redhat.com> 2.0.0.1-5
- update to rhs-nfs-ganesha script, fixes from Meghana

* Mon Dec 23 2013 Anand Subramanian <anands@redhat.com> 2.0.0.1-4
- corrected file permissions for sample nfs-ganesha.conf file
 
* Fri Dec 20 2013 Anand Subramanian <anands@redhat.com> 2.0.0.1-3
- updated Release to 3 with changes to rhs-nfs_ganesha script

* Fri Dec 13 2013 Anand Subramanian <anands@redhat.com> - 2.0.0.1-2
- updated rhs ganesha start/stop script

* Thu Dec 12 2013 Bala.FA <barumuga at redhat.com> - 2.0.0-1
- Initial commit
